@@ -41,7 +41,7 @@ class ProductType(Enum):
 def _is_user_prod(product_id: str or SpeasyIndex, collection: Dict):
     xmlid = to_xmlid(product_id)
     if xmlid in collection:
-        return not collection[xmlid].is_public
+        return is_private(collection[xmlid])
     return False
 
 
@@ -78,7 +78,7 @@ class AMDA_Webservice(DataProvider):
 
     """
 
-    def __init__(self, server_url: str = "http://amda.irap.omp.eu"):
+    def __init__(self, server_url: str = amda_cfg.entry_point()):
         from ._impl import AmdaImpl
         self._impl = AmdaImpl(server_url=server_url)
         DataProvider.__init__(self, provider_name='amda')
@@ -119,17 +119,17 @@ class AMDA_Webservice(DataProvider):
 
     def parameter_range(self, parameter_id: str or ParameterIndex) -> Optional[DateTimeRange]:
         """Get product time range.
-        
+
         Parameters
         ----------
         parameter_id: str or ParameterIndex
             parameter id
-            
+
         Returns
         -------
         Optional[DateTimeRange]
             Data time range
-            
+
         Examples
         --------
         >>> import speasy as spz
@@ -140,17 +140,17 @@ class AMDA_Webservice(DataProvider):
 
     def dataset_range(self, dataset_id: str or DatasetIndex) -> Optional[DateTimeRange]:
         """Get product time range.
-        
+
         Parameters
         ----------
         dataset_id: str or DatasetIndex
             parameter id
-            
+
         Returns
         -------
         Optional[DateTimeRange]
             Data time range
-            
+
         Examples
         --------
         >>> import speasy as spz
@@ -160,8 +160,8 @@ class AMDA_Webservice(DataProvider):
 
         return self._dataset_range(dataset_id)
 
-    def get_data(self, product, start_time=None, stop_time=None, **kwargs) -> Optional[Union[
-        SpeasyVariable, TimeTable, Catalog, Dataset]]:
+    def get_data(self, product, start_time=None, stop_time=None,
+                 **kwargs) -> Optional[Union[SpeasyVariable, TimeTable, Catalog, Dataset]]:
         """Get product data by id.
 
         Parameters
@@ -317,9 +317,8 @@ class AMDA_Webservice(DataProvider):
     @ParameterRangeCheck()
     @Cacheable(prefix="amda", version=product_version, fragment_hours=lambda x: 12)
     @Proxyfiable(GetProduct, get_parameter_args)
-    def get_parameter(self, product, start_time, stop_time, extra_http_headers: Dict or None = None, **kwargs) -> \
-    Optional[
-        SpeasyVariable]:
+    def get_parameter(self, product, start_time, stop_time,
+                      extra_http_headers: Dict or None = None, **kwargs) -> Optional[SpeasyVariable]:
         """Get parameter data.
 
         Parameters
@@ -618,8 +617,7 @@ class AMDA_Webservice(DataProvider):
         """
         return list(filter(is_public, self.flat_inventory.datasets.values()))
 
-    def _find_parent_dataset(self, product_id: str or DatasetIndex or ParameterIndex or ComponentIndex) -> \
-        Optional[str]:
+    def _find_parent_dataset(self, product_id: str or DatasetIndex or ParameterIndex or ComponentIndex) -> Optional[str]:
 
         product_id = to_xmlid(product_id)
         product_type = self.product_type(product_id)
