@@ -1,9 +1,9 @@
 from ._xml_catalogs_parser import load_xml_catalog
 from ._cdf_masters_parser import update_tree
 from ....core.index import index
+from speasy.core import http 
 from ....core.inventory.indexes import SpeasyIndex, to_dict, from_dict
 from ....config import cdaweb as cda_cfg
-import requests
 from tempfile import NamedTemporaryFile
 import tarfile
 import os
@@ -28,14 +28,14 @@ def _clean_master_cdf_folder():
 
 def _download_and_extract_master_cdf(masters_url: str):
     with NamedTemporaryFile('wb') as master_archive:
-        master_archive.write(requests.get(masters_url).content)
+        master_archive.write(http.get(masters_url).content)
         master_archive.flush()
         tar = tarfile.open(master_archive.name)
         tar.extractall(_MASTERS_CDF_PATH)
 
 
 def update_master_cdf(masters_url: str = "https://spdf.gsfc.nasa.gov/pub/software/cdawlib/0MASTERS/master.tar"):
-    last_modified = requests.head(masters_url).headers['last-modified']
+    last_modified = http.get(masters_url, head_only=True).headers['last-modified']
     if index.get("cdaweb-inventory", "masters-last-modified", "") != last_modified:
         _clean_master_cdf_folder()
         _download_and_extract_master_cdf(masters_url)
@@ -45,11 +45,11 @@ def update_master_cdf(masters_url: str = "https://spdf.gsfc.nasa.gov/pub/softwar
 
 
 def update_xml_catalog(xml_catalog_url: str = "https://spdf.gsfc.nasa.gov/pub/catalogs/all.xml"):
-    last_modified = requests.head(xml_catalog_url).headers['last-modified']
+    last_modified = http.get(xml_catalog_url, head_only=True).headers['last-modified']
     if index.get("cdaweb-inventory", "xml_catalog-last-modified", "") != last_modified:
         _ensure_path_exists(_XML_CATALOG_PATH)
         with open(_XML_CATALOG_PATH, 'w') as f:
-            f.write(requests.get(xml_catalog_url).text)
+            f.write(http.get(xml_catalog_url).text)
             index.set("cdaweb-inventory", "xml_catalog-last-modified", last_modified)
             return True
     return False
